from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventActor(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ACTOR_UNSPECIFIED: _ClassVar[EventActor]
    HUMAN: _ClassVar[EventActor]
    MACHINE: _ClassVar[EventActor]
    API: _ClassVar[EventActor]

class Source(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SOURCE_UNSPECIFIED: _ClassVar[Source]
    SCALEKIT: _ClassVar[Source]
    DIR_SYNC: _ClassVar[Source]

class EventTarget(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_TARGET_UNSPECIFIED: _ClassVar[EventTarget]
    WORKSPACE: _ClassVar[EventTarget]
    ENVIRONMENT: _ClassVar[EventTarget]
    ORGANIZATION: _ClassVar[EventTarget]
    USER: _ClassVar[EventTarget]
    SESSION: _ClassVar[EventTarget]
    TEMPLATE: _ClassVar[EventTarget]
    EMAIL_SERVER: _ClassVar[EventTarget]
    EMAIL: _ClassVar[EventTarget]

class EventCategory(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EVENT_SOURCE_UNSPECIFIED: _ClassVar[EventCategory]
    CORE: _ClassVar[EventCategory]
    SSO: _ClassVar[EventCategory]
    DIRSYNC: _ClassVar[EventCategory]

class ObjectType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OBJECT_TYPE_UNSPECIFIED: _ClassVar[ObjectType]
    Workspace: _ClassVar[ObjectType]
    Environment: _ClassVar[ObjectType]
    Organization: _ClassVar[ObjectType]
    Connection: _ClassVar[ObjectType]
    User: _ClassVar[ObjectType]
    Role: _ClassVar[ObjectType]
    CustomAttributes: _ClassVar[ObjectType]
    Directory: _ClassVar[ObjectType]
    DirectoryUser: _ClassVar[ObjectType]
    DirectoryGroup: _ClassVar[ObjectType]
    Session: _ClassVar[ObjectType]
    Template: _ClassVar[ObjectType]
    Job: _ClassVar[ObjectType]
    Domain: _ClassVar[ObjectType]
    EmailServer: _ClassVar[ObjectType]
    Email: _ClassVar[ObjectType]
    AuthRequest: _ClassVar[ObjectType]
    SAMLRequest: _ClassVar[ObjectType]
    SAMLResponse: _ClassVar[ObjectType]
    TokenClaims: _ClassVar[ObjectType]
    OIDCReqParams: _ClassVar[ObjectType]
    OIDCRespClaims: _ClassVar[ObjectType]
    SSOError: _ClassVar[ObjectType]
    GenericError: _ClassVar[ObjectType]
    RefreshTokens: _ClassVar[ObjectType]
    EndSessionRequest: _ClassVar[ObjectType]
    LogoutTokenClaims: _ClassVar[ObjectType]
    OAuthResponse: _ClassVar[ObjectType]
    JSON: _ClassVar[ObjectType]
    SKErrors: _ClassVar[ObjectType]
    OrgMembership: _ClassVar[ObjectType]
    UserProfile: _ClassVar[ObjectType]
    IDPInitiatedPayload: _ClassVar[ObjectType]
    DeviceDetails: _ClassVar[ObjectType]
ACTOR_UNSPECIFIED: EventActor
HUMAN: EventActor
MACHINE: EventActor
API: EventActor
SOURCE_UNSPECIFIED: Source
SCALEKIT: Source
DIR_SYNC: Source
EVENT_TARGET_UNSPECIFIED: EventTarget
WORKSPACE: EventTarget
ENVIRONMENT: EventTarget
ORGANIZATION: EventTarget
USER: EventTarget
SESSION: EventTarget
TEMPLATE: EventTarget
EMAIL_SERVER: EventTarget
EMAIL: EventTarget
EVENT_SOURCE_UNSPECIFIED: EventCategory
CORE: EventCategory
SSO: EventCategory
DIRSYNC: EventCategory
OBJECT_TYPE_UNSPECIFIED: ObjectType
Workspace: ObjectType
Environment: ObjectType
Organization: ObjectType
Connection: ObjectType
User: ObjectType
Role: ObjectType
CustomAttributes: ObjectType
Directory: ObjectType
DirectoryUser: ObjectType
DirectoryGroup: ObjectType
Session: ObjectType
Template: ObjectType
Job: ObjectType
Domain: ObjectType
EmailServer: ObjectType
Email: ObjectType
AuthRequest: ObjectType
SAMLRequest: ObjectType
SAMLResponse: ObjectType
TokenClaims: ObjectType
OIDCReqParams: ObjectType
OIDCRespClaims: ObjectType
SSOError: ObjectType
GenericError: ObjectType
RefreshTokens: ObjectType
EndSessionRequest: ObjectType
LogoutTokenClaims: ObjectType
OAuthResponse: ObjectType
JSON: ObjectType
SKErrors: ObjectType
OrgMembership: ObjectType
UserProfile: ObjectType
IDPInitiatedPayload: ObjectType
DeviceDetails: ObjectType

class SendCustomEventRequest(_message.Message):
    __slots__ = ("event_type", "event")
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    event_type: str
    event: _struct_pb2.Struct
    def __init__(self, event_type: _Optional[str] = ..., event: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class SendCustomEventResponse(_message.Message):
    __slots__ = ("event_id",)
    EVENT_ID_FIELD_NUMBER: _ClassVar[int]
    event_id: str
    def __init__(self, event_id: _Optional[str] = ...) -> None: ...

class IEventPaginationTokens(_message.Message):
    __slots__ = ("NextPage", "PreviousPage", "Total")
    NEXTPAGE_FIELD_NUMBER: _ClassVar[int]
    PREVIOUSPAGE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    NextPage: str
    PreviousPage: str
    Total: int
    def __init__(self, NextPage: _Optional[str] = ..., PreviousPage: _Optional[str] = ..., Total: _Optional[int] = ...) -> None: ...

class ListEventsRequest(_message.Message):
    __slots__ = ("filter", "page_size", "page_token")
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    filter: EventFilter
    page_size: int
    page_token: str
    def __init__(self, filter: _Optional[_Union[EventFilter, _Mapping]] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListEventsResponse(_message.Message):
    __slots__ = ("events", "next_page_token", "prev_page_token", "total_size")
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    events: _containers.RepeatedCompositeFieldContainer[ScalekitEvent]
    next_page_token: str
    prev_page_token: str
    total_size: int
    def __init__(self, events: _Optional[_Iterable[_Union[ScalekitEvent, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., prev_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class IEvent(_message.Message):
    __slots__ = ("spec_version", "id", "type", "occurred_at", "actor", "tenant_id", "target", "source", "data", "old_data", "context", "metadata")
    class ContextEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    SPEC_VERSION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    OCCURRED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTOR_FIELD_NUMBER: _ClassVar[int]
    TENANT_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    OLD_DATA_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    spec_version: str
    id: str
    type: str
    occurred_at: _timestamp_pb2.Timestamp
    actor: Actor
    tenant_id: str
    target: Target
    source: str
    data: _struct_pb2.Struct
    old_data: _struct_pb2.Struct
    context: _containers.ScalarMap[str, str]
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, spec_version: _Optional[str] = ..., id: _Optional[str] = ..., type: _Optional[str] = ..., occurred_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., actor: _Optional[_Union[Actor, _Mapping]] = ..., tenant_id: _Optional[str] = ..., target: _Optional[_Union[Target, _Mapping]] = ..., source: _Optional[str] = ..., data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., old_data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., context: _Optional[_Mapping[str, str]] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Event(_message.Message):
    __slots__ = ("spec_version", "id", "type", "occurred_at", "actor", "tenant_id", "target", "source", "data", "old_data", "context", "metadata", "object")
    class ContextEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    SPEC_VERSION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    OCCURRED_AT_FIELD_NUMBER: _ClassVar[int]
    ACTOR_FIELD_NUMBER: _ClassVar[int]
    TENANT_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    OLD_DATA_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    spec_version: str
    id: str
    type: str
    occurred_at: _timestamp_pb2.Timestamp
    actor: Actor
    tenant_id: str
    target: Target
    source: str
    data: _struct_pb2.Struct
    old_data: _struct_pb2.Struct
    context: _containers.ScalarMap[str, str]
    metadata: _containers.ScalarMap[str, str]
    object: ObjectType
    def __init__(self, spec_version: _Optional[str] = ..., id: _Optional[str] = ..., type: _Optional[str] = ..., occurred_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., actor: _Optional[_Union[Actor, _Mapping]] = ..., tenant_id: _Optional[str] = ..., target: _Optional[_Union[Target, _Mapping]] = ..., source: _Optional[str] = ..., data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., old_data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., context: _Optional[_Mapping[str, str]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., object: _Optional[_Union[ObjectType, str]] = ...) -> None: ...

class Actor(_message.Message):
    __slots__ = ("id", "type")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: EventActor
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[EventActor, str]] = ...) -> None: ...

class Target(_message.Message):
    __slots__ = ("id", "type")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: EventTarget
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[EventTarget, str]] = ...) -> None: ...

class IEventFilter(_message.Message):
    __slots__ = ("event_types", "start_time", "end_time", "tenant_id", "target", "source", "metadata", "internal_events")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    EVENT_TYPES_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    TENANT_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_EVENTS_FIELD_NUMBER: _ClassVar[int]
    event_types: _containers.RepeatedScalarFieldContainer[str]
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    tenant_id: str
    target: Target
    source: Source
    metadata: _containers.ScalarMap[str, str]
    internal_events: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, event_types: _Optional[_Iterable[str]] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., tenant_id: _Optional[str] = ..., target: _Optional[_Union[Target, _Mapping]] = ..., source: _Optional[_Union[Source, str]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., internal_events: _Optional[_Iterable[str]] = ...) -> None: ...

class EventFilter(_message.Message):
    __slots__ = ("event_types", "start_time", "end_time", "organization_id", "source", "auth_request_id")
    EVENT_TYPES_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    AUTH_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    event_types: _containers.RepeatedScalarFieldContainer[str]
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    organization_id: str
    source: Source
    auth_request_id: str
    def __init__(self, event_types: _Optional[_Iterable[str]] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., organization_id: _Optional[str] = ..., source: _Optional[_Union[Source, str]] = ..., auth_request_id: _Optional[str] = ...) -> None: ...

class ScalekitEvent(_message.Message):
    __slots__ = ("spec_version", "id", "type", "occurred_at", "environment_id", "organization_id", "object", "data", "display_name")
    SPEC_VERSION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    OCCURRED_AT_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    spec_version: str
    id: str
    type: str
    occurred_at: _timestamp_pb2.Timestamp
    environment_id: str
    organization_id: str
    object: ObjectType
    data: _struct_pb2.Struct
    display_name: str
    def __init__(self, spec_version: _Optional[str] = ..., id: _Optional[str] = ..., type: _Optional[str] = ..., occurred_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., environment_id: _Optional[str] = ..., organization_id: _Optional[str] = ..., object: _Optional[_Union[ObjectType, str]] = ..., data: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., display_name: _Optional[str] = ...) -> None: ...



from typing import Optional, Dict, Any, List
from pydantic import BaseModel, Field
from google.protobuf.json_format import MessageToDict

from scalekit.connect.models.tool_mapping import ToolMapping


class CreateMcpResponse(BaseModel):
    """Create MCP response with one-to-one mapping to proto CreateMcpResponse"""
    
    id: Optional[str]
    identifier: Optional[str]
    url: Optional[str]
    tool_mappings: Optional[List[ToolMapping]]

    @classmethod
    def from_proto(cls, proto_response) -> 'CreateMcpResponse':
        """
        Create CreateMcpResponse from protobuf CreateMcpResponse
        
        :param proto_response: The protobuf CreateMcpResponse object
        :type proto_response: CreateMcpResponse (from mcp_pb2)
        
        :returns:
            CreateMcpResponse instance
        """
        mcp = proto_response.mcp if proto_response.mcp else None
        
        if mcp:
            # Convert tool_mappings from protobuf to dict
            tool_mappings = []
            if mcp.tool_mappings:
                for mapping in mcp.tool_mappings:
                    tool_mappings.append(
                        ToolMapping.from_proto(mapping)
                    )
            
            return cls(
                id=mcp.id if mcp.id else None,
                identifier=mcp.connected_account_identifier if mcp.connected_account_identifier else None,
                tool_mappings=tool_mappings if tool_mappings else None,
                url=mcp.url if mcp.url else None
            )
        
        return cls()

    def to_dict(self) -> Dict[str, Any]:
        """
        Convert to dictionary representation
        
        :returns:
            Dictionary representation of the response
        """
        return {
            "id": self.mcp_id,
            "identifier": self.connected_account_identifier,
            "tool_mappings": self.tool_mappings,
            "url": self.url
        }


from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ResourceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    RESOURCE_TYPE_UNSPECIFIED: _ClassVar[ResourceType]
    WEB: _ClassVar[ResourceType]
    MOBILE: _ClassVar[ResourceType]
    DESKTOP: _ClassVar[ResourceType]
    SERVER: _ClassVar[ResourceType]
    MCP_SERVER: _ClassVar[ResourceType]

class ClientSecretStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ACTIVE: _ClassVar[ClientSecretStatus]
    INACTIVE: _ClassVar[ClientSecretStatus]
RESOURCE_TYPE_UNSPECIFIED: ResourceType
WEB: ResourceType
MOBILE: ResourceType
DESKTOP: ResourceType
SERVER: ResourceType
MCP_SERVER: ResourceType
ACTIVE: ClientSecretStatus
INACTIVE: ClientSecretStatus

class CreateResourceRequest(_message.Message):
    __slots__ = ("resource",)
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    resource: CreateResource
    def __init__(self, resource: _Optional[_Union[CreateResource, _Mapping]] = ...) -> None: ...

class CreateResource(_message.Message):
    __slots__ = ("resource_type", "name", "description", "resource_uri", "access_token_expiry", "refresh_token_expiry", "disable_dynamic_client_registration", "logo_uri", "provider", "resource_id", "scopes")
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_URI_FIELD_NUMBER: _ClassVar[int]
    ACCESS_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    DISABLE_DYNAMIC_CLIENT_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    resource_type: ResourceType
    name: str
    description: str
    resource_uri: str
    access_token_expiry: int
    refresh_token_expiry: int
    disable_dynamic_client_registration: bool
    logo_uri: str
    provider: str
    resource_id: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, resource_type: _Optional[_Union[ResourceType, str]] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., resource_uri: _Optional[str] = ..., access_token_expiry: _Optional[int] = ..., refresh_token_expiry: _Optional[int] = ..., disable_dynamic_client_registration: bool = ..., logo_uri: _Optional[str] = ..., provider: _Optional[str] = ..., resource_id: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ...) -> None: ...

class ResourceClient(_message.Message):
    __slots__ = ("name", "description", "scopes", "audience", "custom_claims", "expiry", "redirect_uri")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_CLAIMS_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    audience: _containers.RepeatedScalarFieldContainer[str]
    custom_claims: _containers.RepeatedCompositeFieldContainer[CustomClaim]
    expiry: int
    redirect_uri: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ..., audience: _Optional[_Iterable[str]] = ..., custom_claims: _Optional[_Iterable[_Union[CustomClaim, _Mapping]]] = ..., expiry: _Optional[int] = ..., redirect_uri: _Optional[str] = ...) -> None: ...

class CreateResourceResponse(_message.Message):
    __slots__ = ("resource",)
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    resource: Resource
    def __init__(self, resource: _Optional[_Union[Resource, _Mapping]] = ...) -> None: ...

class GetResourceRequest(_message.Message):
    __slots__ = ("resource_id",)
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    def __init__(self, resource_id: _Optional[str] = ...) -> None: ...

class GetResourceResponse(_message.Message):
    __slots__ = ("resource",)
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    resource: Resource
    def __init__(self, resource: _Optional[_Union[Resource, _Mapping]] = ...) -> None: ...

class DeleteResourceProviderRequest(_message.Message):
    __slots__ = ("resource_id",)
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    def __init__(self, resource_id: _Optional[str] = ...) -> None: ...

class DeleteResourceRequest(_message.Message):
    __slots__ = ("resource_id",)
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    def __init__(self, resource_id: _Optional[str] = ...) -> None: ...

class Application(_message.Message):
    __slots__ = ("id", "name", "resource_id", "description", "application_type", "disable_dynamic_client_registration", "logo_uri", "access_token_expiry", "refresh_token_expiry", "create_time", "update_time", "provider")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    DISABLE_DYNAMIC_CLIENT_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    ACCESS_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    resource_id: str
    description: str
    application_type: ResourceType
    disable_dynamic_client_registration: bool
    logo_uri: str
    access_token_expiry: int
    refresh_token_expiry: int
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    provider: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., resource_id: _Optional[str] = ..., description: _Optional[str] = ..., application_type: _Optional[_Union[ResourceType, str]] = ..., disable_dynamic_client_registration: bool = ..., logo_uri: _Optional[str] = ..., access_token_expiry: _Optional[int] = ..., refresh_token_expiry: _Optional[int] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., provider: _Optional[str] = ...) -> None: ...

class Resource(_message.Message):
    __slots__ = ("id", "name", "resource_uri", "description", "resource_type", "disable_dynamic_client_registration", "logo_uri", "access_token_expiry", "refresh_token_expiry", "create_time", "update_time", "provider", "protected_metadata", "protected_metadata_uri", "resource_id", "scopes")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_URI_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    DISABLE_DYNAMIC_CLIENT_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    ACCESS_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    PROTECTED_METADATA_FIELD_NUMBER: _ClassVar[int]
    PROTECTED_METADATA_URI_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    resource_uri: str
    description: str
    resource_type: ResourceType
    disable_dynamic_client_registration: bool
    logo_uri: str
    access_token_expiry: int
    refresh_token_expiry: int
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    provider: str
    protected_metadata: _struct_pb2.Struct
    protected_metadata_uri: str
    resource_id: str
    scopes: _containers.RepeatedCompositeFieldContainer[Scope]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., resource_uri: _Optional[str] = ..., description: _Optional[str] = ..., resource_type: _Optional[_Union[ResourceType, str]] = ..., disable_dynamic_client_registration: bool = ..., logo_uri: _Optional[str] = ..., access_token_expiry: _Optional[int] = ..., refresh_token_expiry: _Optional[int] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., provider: _Optional[str] = ..., protected_metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., protected_metadata_uri: _Optional[str] = ..., resource_id: _Optional[str] = ..., scopes: _Optional[_Iterable[_Union[Scope, _Mapping]]] = ...) -> None: ...

class RegisterClientRequest(_message.Message):
    __slots__ = ("res_id", "client")
    RES_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    res_id: str
    client: RegisterClient
    def __init__(self, res_id: _Optional[str] = ..., client: _Optional[_Union[RegisterClient, _Mapping]] = ...) -> None: ...

class RegisterClient(_message.Message):
    __slots__ = ("client_name", "description", "redirect_uris", "scope", "client_uri", "logo_uri", "tos_uri", "policy_uri")
    CLIENT_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_URI_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    TOS_URI_FIELD_NUMBER: _ClassVar[int]
    POLICY_URI_FIELD_NUMBER: _ClassVar[int]
    client_name: str
    description: str
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    scope: str
    client_uri: str
    logo_uri: str
    tos_uri: str
    policy_uri: str
    def __init__(self, client_name: _Optional[str] = ..., description: _Optional[str] = ..., redirect_uris: _Optional[_Iterable[str]] = ..., scope: _Optional[str] = ..., client_uri: _Optional[str] = ..., logo_uri: _Optional[str] = ..., tos_uri: _Optional[str] = ..., policy_uri: _Optional[str] = ...) -> None: ...

class RegisterClientResponse(_message.Message):
    __slots__ = ("client_id", "secrets", "name", "description", "create_time", "update_time", "scopes", "audience", "custom_claims", "expiry", "resource_id", "redirect_uris")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SECRETS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_CLAIMS_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    secrets: _containers.RepeatedCompositeFieldContainer[ClientSecret]
    name: str
    description: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    scopes: _containers.RepeatedScalarFieldContainer[str]
    audience: _containers.RepeatedScalarFieldContainer[str]
    custom_claims: _containers.RepeatedCompositeFieldContainer[CustomClaim]
    expiry: int
    resource_id: str
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, client_id: _Optional[str] = ..., secrets: _Optional[_Iterable[_Union[ClientSecret, _Mapping]]] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., scopes: _Optional[_Iterable[str]] = ..., audience: _Optional[_Iterable[str]] = ..., custom_claims: _Optional[_Iterable[_Union[CustomClaim, _Mapping]]] = ..., expiry: _Optional[int] = ..., resource_id: _Optional[str] = ..., redirect_uris: _Optional[_Iterable[str]] = ...) -> None: ...

class ListResourcesRequest(_message.Message):
    __slots__ = ("resource_type", "page_token", "page_size")
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    resource_type: ResourceType
    page_token: str
    page_size: int
    def __init__(self, resource_type: _Optional[_Union[ResourceType, str]] = ..., page_token: _Optional[str] = ..., page_size: _Optional[int] = ...) -> None: ...

class ListResourcesResponse(_message.Message):
    __slots__ = ("total_size", "next_page_token", "resources")
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    total_size: int
    next_page_token: str
    resources: _containers.RepeatedCompositeFieldContainer[Resource]
    def __init__(self, total_size: _Optional[int] = ..., next_page_token: _Optional[str] = ..., resources: _Optional[_Iterable[_Union[Resource, _Mapping]]] = ...) -> None: ...

class UpdateResourceRequest(_message.Message):
    __slots__ = ("resource_id", "resource", "update_mask")
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    resource: UpdateResource
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, resource_id: _Optional[str] = ..., resource: _Optional[_Union[UpdateResource, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UpdateResource(_message.Message):
    __slots__ = ("name", "description", "resource_uri", "access_token_expiry", "refresh_token_expiry", "disable_dynamic_client_registration", "logo_uri", "provider", "resource_id", "scopes")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_URI_FIELD_NUMBER: _ClassVar[int]
    ACCESS_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_EXPIRY_FIELD_NUMBER: _ClassVar[int]
    DISABLE_DYNAMIC_CLIENT_REGISTRATION_FIELD_NUMBER: _ClassVar[int]
    LOGO_URI_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    resource_uri: str
    access_token_expiry: int
    refresh_token_expiry: int
    disable_dynamic_client_registration: bool
    logo_uri: str
    provider: str
    resource_id: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., resource_uri: _Optional[str] = ..., access_token_expiry: _Optional[int] = ..., refresh_token_expiry: _Optional[int] = ..., disable_dynamic_client_registration: bool = ..., logo_uri: _Optional[str] = ..., provider: _Optional[str] = ..., resource_id: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateResourceResponse(_message.Message):
    __slots__ = ("resource",)
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    resource: Resource
    def __init__(self, resource: _Optional[_Union[Resource, _Mapping]] = ...) -> None: ...

class CreateResourceClientRequest(_message.Message):
    __slots__ = ("resource_id", "client")
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    client: ResourceClient
    def __init__(self, resource_id: _Optional[str] = ..., client: _Optional[_Union[ResourceClient, _Mapping]] = ...) -> None: ...

class CreateResourceClientResponse(_message.Message):
    __slots__ = ("client", "plain_secret")
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    PLAIN_SECRET_FIELD_NUMBER: _ClassVar[int]
    client: M2MClient
    plain_secret: str
    def __init__(self, client: _Optional[_Union[M2MClient, _Mapping]] = ..., plain_secret: _Optional[str] = ...) -> None: ...

class GetResourceClientRequest(_message.Message):
    __slots__ = ("resource_id", "client_id")
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    resource_id: str
    client_id: str
    def __init__(self, resource_id: _Optional[str] = ..., client_id: _Optional[str] = ...) -> None: ...

class GetResourceClientResponse(_message.Message):
    __slots__ = ("resource", "client")
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    resource: Resource
    client: M2MClient
    def __init__(self, resource: _Optional[_Union[Resource, _Mapping]] = ..., client: _Optional[_Union[M2MClient, _Mapping]] = ...) -> None: ...

class CreateOrganizationClientRequest(_message.Message):
    __slots__ = ("organization_id", "client")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    client: OrganizationClient
    def __init__(self, organization_id: _Optional[str] = ..., client: _Optional[_Union[OrganizationClient, _Mapping]] = ...) -> None: ...

class OrganizationClient(_message.Message):
    __slots__ = ("name", "description", "scopes", "audience", "custom_claims", "expiry")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_CLAIMS_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    audience: _containers.RepeatedScalarFieldContainer[str]
    custom_claims: _containers.RepeatedCompositeFieldContainer[CustomClaim]
    expiry: int
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., scopes: _Optional[_Iterable[str]] = ..., audience: _Optional[_Iterable[str]] = ..., custom_claims: _Optional[_Iterable[_Union[CustomClaim, _Mapping]]] = ..., expiry: _Optional[int] = ...) -> None: ...

class CreateOrganizationClientResponse(_message.Message):
    __slots__ = ("client", "plain_secret")
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    PLAIN_SECRET_FIELD_NUMBER: _ClassVar[int]
    client: M2MClient
    plain_secret: str
    def __init__(self, client: _Optional[_Union[M2MClient, _Mapping]] = ..., plain_secret: _Optional[str] = ...) -> None: ...

class UpdateOrganizationClientRequest(_message.Message):
    __slots__ = ("organization_id", "client_id", "client")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    client_id: str
    client: OrganizationClient
    def __init__(self, organization_id: _Optional[str] = ..., client_id: _Optional[str] = ..., client: _Optional[_Union[OrganizationClient, _Mapping]] = ...) -> None: ...

class UpdateOrganizationClientResponse(_message.Message):
    __slots__ = ("client",)
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    client: M2MClient
    def __init__(self, client: _Optional[_Union[M2MClient, _Mapping]] = ...) -> None: ...

class M2MClient(_message.Message):
    __slots__ = ("client_id", "secrets", "name", "description", "organization_id", "create_time", "update_time", "scopes", "audience", "custom_claims", "expiry", "resource_id", "redirect_uris")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SECRETS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_CLAIMS_FIELD_NUMBER: _ClassVar[int]
    EXPIRY_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    secrets: _containers.RepeatedCompositeFieldContainer[ClientSecret]
    name: str
    description: str
    organization_id: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    scopes: _containers.RepeatedScalarFieldContainer[str]
    audience: _containers.RepeatedScalarFieldContainer[str]
    custom_claims: _containers.RepeatedCompositeFieldContainer[CustomClaim]
    expiry: int
    resource_id: str
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, client_id: _Optional[str] = ..., secrets: _Optional[_Iterable[_Union[ClientSecret, _Mapping]]] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., organization_id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., scopes: _Optional[_Iterable[str]] = ..., audience: _Optional[_Iterable[str]] = ..., custom_claims: _Optional[_Iterable[_Union[CustomClaim, _Mapping]]] = ..., expiry: _Optional[int] = ..., resource_id: _Optional[str] = ..., redirect_uris: _Optional[_Iterable[str]] = ...) -> None: ...

class GetOrganizationClientRequest(_message.Message):
    __slots__ = ("organization_id", "client_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    client_id: str
    def __init__(self, organization_id: _Optional[str] = ..., client_id: _Optional[str] = ...) -> None: ...

class GetOrganizationClientResponse(_message.Message):
    __slots__ = ("client",)
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    client: M2MClient
    def __init__(self, client: _Optional[_Union[M2MClient, _Mapping]] = ...) -> None: ...

class CustomClaim(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class CreateOrganizationClientSecretRequest(_message.Message):
    __slots__ = ("organization_id", "client_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    client_id: str
    def __init__(self, organization_id: _Optional[str] = ..., client_id: _Optional[str] = ...) -> None: ...

class CreateOrganizationClientSecretResponse(_message.Message):
    __slots__ = ("plain_secret", "secret")
    PLAIN_SECRET_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    plain_secret: str
    secret: ClientSecret
    def __init__(self, plain_secret: _Optional[str] = ..., secret: _Optional[_Union[ClientSecret, _Mapping]] = ...) -> None: ...

class DeleteOrganizationClientSecretRequest(_message.Message):
    __slots__ = ("organization_id", "client_id", "secret_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    client_id: str
    secret_id: str
    def __init__(self, organization_id: _Optional[str] = ..., client_id: _Optional[str] = ..., secret_id: _Optional[str] = ...) -> None: ...

class ListOrganizationClientsRequest(_message.Message):
    __slots__ = ("organization_id", "page_size", "page_token")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    page_size: int
    page_token: str
    def __init__(self, organization_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListOrganizationClientsResponse(_message.Message):
    __slots__ = ("next_page_token", "total_size", "clients", "prev_page_token")
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    total_size: int
    clients: _containers.RepeatedCompositeFieldContainer[M2MClient]
    prev_page_token: str
    def __init__(self, next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., clients: _Optional[_Iterable[_Union[M2MClient, _Mapping]]] = ..., prev_page_token: _Optional[str] = ...) -> None: ...

class DeleteOrganizationClientRequest(_message.Message):
    __slots__ = ("organization_id", "client_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    client_id: str
    def __init__(self, organization_id: _Optional[str] = ..., client_id: _Optional[str] = ...) -> None: ...

class GetClientRequest(_message.Message):
    __slots__ = ("client_id",)
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    def __init__(self, client_id: _Optional[str] = ...) -> None: ...

class GetClientResponse(_message.Message):
    __slots__ = ("client",)
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    client: Client
    def __init__(self, client: _Optional[_Union[Client, _Mapping]] = ...) -> None: ...

class ListClientsRequest(_message.Message):
    __slots__ = ("include_plain_secret",)
    INCLUDE_PLAIN_SECRET_FIELD_NUMBER: _ClassVar[int]
    include_plain_secret: bool
    def __init__(self, include_plain_secret: bool = ...) -> None: ...

class ListClientsResponse(_message.Message):
    __slots__ = ("total_size", "clients")
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    total_size: int
    clients: _containers.RepeatedCompositeFieldContainer[Client]
    def __init__(self, total_size: _Optional[int] = ..., clients: _Optional[_Iterable[_Union[Client, _Mapping]]] = ...) -> None: ...

class UpdateClientRequest(_message.Message):
    __slots__ = ("client_id", "client", "mask")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    MASK_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client: UpdateClient
    mask: _field_mask_pb2.FieldMask
    def __init__(self, client_id: _Optional[str] = ..., client: _Optional[_Union[UpdateClient, _Mapping]] = ..., mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UpdateClient(_message.Message):
    __slots__ = ("redirect_uris", "default_redirect_uri", "back_channel_logout_uris", "post_logout_redirect_uris", "initiate_login_uri", "post_login_uris")
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    BACK_CHANNEL_LOGOUT_URIS_FIELD_NUMBER: _ClassVar[int]
    POST_LOGOUT_REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    INITIATE_LOGIN_URI_FIELD_NUMBER: _ClassVar[int]
    POST_LOGIN_URIS_FIELD_NUMBER: _ClassVar[int]
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    default_redirect_uri: str
    back_channel_logout_uris: _containers.RepeatedScalarFieldContainer[str]
    post_logout_redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    initiate_login_uri: str
    post_login_uris: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, redirect_uris: _Optional[_Iterable[str]] = ..., default_redirect_uri: _Optional[str] = ..., back_channel_logout_uris: _Optional[_Iterable[str]] = ..., post_logout_redirect_uris: _Optional[_Iterable[str]] = ..., initiate_login_uri: _Optional[str] = ..., post_login_uris: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateClientResponse(_message.Message):
    __slots__ = ("client",)
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    client: Client
    def __init__(self, client: _Optional[_Union[Client, _Mapping]] = ...) -> None: ...

class CreateClientSecretRequest(_message.Message):
    __slots__ = ("client_id",)
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    def __init__(self, client_id: _Optional[str] = ...) -> None: ...

class CreateClientSecretResponse(_message.Message):
    __slots__ = ("plain_secret", "secret")
    PLAIN_SECRET_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    plain_secret: str
    secret: ClientSecret
    def __init__(self, plain_secret: _Optional[str] = ..., secret: _Optional[_Union[ClientSecret, _Mapping]] = ...) -> None: ...

class UpdateClientSecretRequest(_message.Message):
    __slots__ = ("client_id", "secret_id", "secret", "mask")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    MASK_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    secret_id: str
    secret: UpdateClientSecret
    mask: _field_mask_pb2.FieldMask
    def __init__(self, client_id: _Optional[str] = ..., secret_id: _Optional[str] = ..., secret: _Optional[_Union[UpdateClientSecret, _Mapping]] = ..., mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UpdateClientSecret(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: ClientSecretStatus
    def __init__(self, status: _Optional[_Union[ClientSecretStatus, str]] = ...) -> None: ...

class UpdateClientSecretResponse(_message.Message):
    __slots__ = ("secret",)
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: ClientSecret
    def __init__(self, secret: _Optional[_Union[ClientSecret, _Mapping]] = ...) -> None: ...

class DeleteClientSecretRequest(_message.Message):
    __slots__ = ("client_id", "secret_id")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_ID_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    secret_id: str
    def __init__(self, client_id: _Optional[str] = ..., secret_id: _Optional[str] = ...) -> None: ...

class Client(_message.Message):
    __slots__ = ("id", "keyId", "create_time", "update_time", "redirect_uris", "default_redirect_uri", "secrets", "post_logout_redirect_uris", "back_channel_logout_uris", "initiate_login_uri", "post_login_uris")
    ID_FIELD_NUMBER: _ClassVar[int]
    KEYID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    SECRETS_FIELD_NUMBER: _ClassVar[int]
    POST_LOGOUT_REDIRECT_URIS_FIELD_NUMBER: _ClassVar[int]
    BACK_CHANNEL_LOGOUT_URIS_FIELD_NUMBER: _ClassVar[int]
    INITIATE_LOGIN_URI_FIELD_NUMBER: _ClassVar[int]
    POST_LOGIN_URIS_FIELD_NUMBER: _ClassVar[int]
    id: str
    keyId: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    default_redirect_uri: str
    secrets: _containers.RepeatedCompositeFieldContainer[ClientSecret]
    post_logout_redirect_uris: _containers.RepeatedScalarFieldContainer[str]
    back_channel_logout_uris: _containers.RepeatedScalarFieldContainer[str]
    initiate_login_uri: str
    post_login_uris: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., keyId: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., redirect_uris: _Optional[_Iterable[str]] = ..., default_redirect_uri: _Optional[str] = ..., secrets: _Optional[_Iterable[_Union[ClientSecret, _Mapping]]] = ..., post_logout_redirect_uris: _Optional[_Iterable[str]] = ..., back_channel_logout_uris: _Optional[_Iterable[str]] = ..., initiate_login_uri: _Optional[str] = ..., post_login_uris: _Optional[_Iterable[str]] = ...) -> None: ...

class ClientSecret(_message.Message):
    __slots__ = ("id", "create_time", "update_time", "secret_suffix", "created_by", "status", "expire_time", "last_used_time", "plain_secret")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    SECRET_SUFFIX_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_USED_TIME_FIELD_NUMBER: _ClassVar[int]
    PLAIN_SECRET_FIELD_NUMBER: _ClassVar[int]
    id: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    secret_suffix: str
    created_by: str
    status: ClientSecretStatus
    expire_time: _timestamp_pb2.Timestamp
    last_used_time: _timestamp_pb2.Timestamp
    plain_secret: str
    def __init__(self, id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., secret_suffix: _Optional[str] = ..., created_by: _Optional[str] = ..., status: _Optional[_Union[ClientSecretStatus, str]] = ..., expire_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_used_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., plain_secret: _Optional[str] = ...) -> None: ...

class Scope(_message.Message):
    __slots__ = ("id", "name", "description", "enabled")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    enabled: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., enabled: bool = ...) -> None: ...

class CreateScope(_message.Message):
    __slots__ = ("name", "description")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class CreateScopeRequest(_message.Message):
    __slots__ = ("scope", "env_id")
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    ENV_ID_FIELD_NUMBER: _ClassVar[int]
    scope: CreateScope
    env_id: str
    def __init__(self, scope: _Optional[_Union[CreateScope, _Mapping]] = ..., env_id: _Optional[str] = ...) -> None: ...

class CreateScopeResponse(_message.Message):
    __slots__ = ("scope",)
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    scope: Scope
    def __init__(self, scope: _Optional[_Union[Scope, _Mapping]] = ...) -> None: ...

class ListScopesRequest(_message.Message):
    __slots__ = ("env_id",)
    ENV_ID_FIELD_NUMBER: _ClassVar[int]
    env_id: str
    def __init__(self, env_id: _Optional[str] = ...) -> None: ...

class ListScopesResponse(_message.Message):
    __slots__ = ("scopes",)
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    scopes: _containers.RepeatedCompositeFieldContainer[Scope]
    def __init__(self, scopes: _Optional[_Iterable[_Union[Scope, _Mapping]]] = ...) -> None: ...

class UpdateScopeRequest(_message.Message):
    __slots__ = ("id", "scope")
    ID_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    id: str
    scope: UpdateScope
    def __init__(self, id: _Optional[str] = ..., scope: _Optional[_Union[UpdateScope, _Mapping]] = ...) -> None: ...

class UpdateScope(_message.Message):
    __slots__ = ("description", "enabled")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    description: str
    enabled: _wrappers_pb2.BoolValue
    def __init__(self, description: _Optional[str] = ..., enabled: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...) -> None: ...

class UpdateScopeResponse(_message.Message):
    __slots__ = ("scope",)
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    scope: Scope
    def __init__(self, scope: _Optional[_Union[Scope, _Mapping]] = ...) -> None: ...

class DeleteScopeRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetConsentDetailsResponse(_message.Message):
    __slots__ = ("resource", "user", "client", "scopes", "application")
    RESOURCE_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_FIELD_NUMBER: _ClassVar[int]
    resource: Resource
    user: User
    client: ConsentClient
    scopes: _containers.RepeatedCompositeFieldContainer[ConsentScope]
    application: Application
    def __init__(self, resource: _Optional[_Union[Resource, _Mapping]] = ..., user: _Optional[_Union[User, _Mapping]] = ..., client: _Optional[_Union[ConsentClient, _Mapping]] = ..., scopes: _Optional[_Iterable[_Union[ConsentScope, _Mapping]]] = ..., application: _Optional[_Union[Application, _Mapping]] = ...) -> None: ...

class ConsentClient(_message.Message):
    __slots__ = ("name", "privacy_uri", "tos_uri")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRIVACY_URI_FIELD_NUMBER: _ClassVar[int]
    TOS_URI_FIELD_NUMBER: _ClassVar[int]
    name: str
    privacy_uri: str
    tos_uri: str
    def __init__(self, name: _Optional[str] = ..., privacy_uri: _Optional[str] = ..., tos_uri: _Optional[str] = ...) -> None: ...

class ConsentScope(_message.Message):
    __slots__ = ("name", "description")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class User(_message.Message):
    __slots__ = ("email",)
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from scalekit.v1.providers import providers_pb2 as scalekit_dot_v1_dot_providers_dot_providers__pb2


class ProviderServiceStub(object):
    """Service definition
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateProvider = channel.unary_unary(
                '/scalekit.v1.providers.ProviderService/CreateProvider',
                request_serializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.CreateProviderRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.CreateProviderResponse.FromString,
                )
        self.UpdateProvider = channel.unary_unary(
                '/scalekit.v1.providers.ProviderService/UpdateProvider',
                request_serializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.UpdateProviderRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.UpdateProviderResponse.FromString,
                )
        self.DeleteProvider = channel.unary_unary(
                '/scalekit.v1.providers.ProviderService/DeleteProvider',
                request_serializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.DeleteProviderRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.DeleteProviderResponse.FromString,
                )
        self.ListProviders = channel.unary_unary(
                '/scalekit.v1.providers.ProviderService/ListProviders',
                request_serializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.ListProvidersRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.ListProvidersResponse.FromString,
                )


class ProviderServiceServicer(object):
    """Service definition
    """

    def CreateProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProviders(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProviderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateProvider,
                    request_deserializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.CreateProviderRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.CreateProviderResponse.SerializeToString,
            ),
            'UpdateProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProvider,
                    request_deserializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.UpdateProviderRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.UpdateProviderResponse.SerializeToString,
            ),
            'DeleteProvider': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProvider,
                    request_deserializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.DeleteProviderRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.DeleteProviderResponse.SerializeToString,
            ),
            'ListProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProviders,
                    request_deserializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.ListProvidersRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_providers_dot_providers__pb2.ListProvidersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.providers.ProviderService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProviderService(object):
    """Service definition
    """

    @staticmethod
    def CreateProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.providers.ProviderService/CreateProvider',
            scalekit_dot_v1_dot_providers_dot_providers__pb2.CreateProviderRequest.SerializeToString,
            scalekit_dot_v1_dot_providers_dot_providers__pb2.CreateProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.providers.ProviderService/UpdateProvider',
            scalekit_dot_v1_dot_providers_dot_providers__pb2.UpdateProviderRequest.SerializeToString,
            scalekit_dot_v1_dot_providers_dot_providers__pb2.UpdateProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProvider(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.providers.ProviderService/DeleteProvider',
            scalekit_dot_v1_dot_providers_dot_providers__pb2.DeleteProviderRequest.SerializeToString,
            scalekit_dot_v1_dot_providers_dot_providers__pb2.DeleteProviderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.providers.ProviderService/ListProviders',
            scalekit_dot_v1_dot_providers_dot_providers__pb2.ListProvidersRequest.SerializeToString,
            scalekit_dot_v1_dot_providers_dot_providers__pb2.ListProvidersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DirectoryType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DIRECTORY_TYPE_UNSPECIFIED: _ClassVar[DirectoryType]
    SCIM: _ClassVar[DirectoryType]
    LDAP: _ClassVar[DirectoryType]
    POLL: _ClassVar[DirectoryType]

class DirectoryProvider(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DIRECTORY_PROVIDER_UNSPECIFIED: _ClassVar[DirectoryProvider]
    OKTA: _ClassVar[DirectoryProvider]
    GOOGLE: _ClassVar[DirectoryProvider]
    MICROSOFT_AD: _ClassVar[DirectoryProvider]
    AUTH0: _ClassVar[DirectoryProvider]
    ONELOGIN: _ClassVar[DirectoryProvider]
    JUMPCLOUD: _ClassVar[DirectoryProvider]
    PING_IDENTITY: _ClassVar[DirectoryProvider]

class DirectoryStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DIRECTORY_STATUS_UNSPECIFIED: _ClassVar[DirectoryStatus]
    DRAFT: _ClassVar[DirectoryStatus]
    IN_PROGRESS: _ClassVar[DirectoryStatus]
    COMPLETED: _ClassVar[DirectoryStatus]

class SecretStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ACTIVE: _ClassVar[SecretStatus]
    INACTIVE: _ClassVar[SecretStatus]
DIRECTORY_TYPE_UNSPECIFIED: DirectoryType
SCIM: DirectoryType
LDAP: DirectoryType
POLL: DirectoryType
DIRECTORY_PROVIDER_UNSPECIFIED: DirectoryProvider
OKTA: DirectoryProvider
GOOGLE: DirectoryProvider
MICROSOFT_AD: DirectoryProvider
AUTH0: DirectoryProvider
ONELOGIN: DirectoryProvider
JUMPCLOUD: DirectoryProvider
PING_IDENTITY: DirectoryProvider
DIRECTORY_STATUS_UNSPECIFIED: DirectoryStatus
DRAFT: DirectoryStatus
IN_PROGRESS: DirectoryStatus
COMPLETED: DirectoryStatus
ACTIVE: SecretStatus
INACTIVE: SecretStatus

class GetDirectoryRequest(_message.Message):
    __slots__ = ("id", "organization_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    organization_id: str
    def __init__(self, id: _Optional[str] = ..., organization_id: _Optional[str] = ...) -> None: ...

class GetDirectoryResponse(_message.Message):
    __slots__ = ("directory",)
    DIRECTORY_FIELD_NUMBER: _ClassVar[int]
    directory: Directory
    def __init__(self, directory: _Optional[_Union[Directory, _Mapping]] = ...) -> None: ...

class CreateDirectoryRequest(_message.Message):
    __slots__ = ("organization_id", "directory")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    directory: CreateDirectory
    def __init__(self, organization_id: _Optional[str] = ..., directory: _Optional[_Union[CreateDirectory, _Mapping]] = ...) -> None: ...

class CreateDirectory(_message.Message):
    __slots__ = ("directory_type", "directory_provider")
    DIRECTORY_TYPE_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    directory_type: DirectoryType
    directory_provider: DirectoryProvider
    def __init__(self, directory_type: _Optional[_Union[DirectoryType, str]] = ..., directory_provider: _Optional[_Union[DirectoryProvider, str]] = ...) -> None: ...

class CreateDirectoryResponse(_message.Message):
    __slots__ = ("directory",)
    DIRECTORY_FIELD_NUMBER: _ClassVar[int]
    directory: Directory
    def __init__(self, directory: _Optional[_Union[Directory, _Mapping]] = ...) -> None: ...

class UpdateDirectoryRequest(_message.Message):
    __slots__ = ("id", "organization_id", "directory")
    ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_FIELD_NUMBER: _ClassVar[int]
    id: str
    organization_id: str
    directory: UpdateDirectory
    def __init__(self, id: _Optional[str] = ..., organization_id: _Optional[str] = ..., directory: _Optional[_Union[UpdateDirectory, _Mapping]] = ...) -> None: ...

class UpdateDirectory(_message.Message):
    __slots__ = ("name", "directory_type", "enabled", "directory_provider", "status", "mappings", "groups")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    name: str
    directory_type: DirectoryType
    enabled: bool
    directory_provider: DirectoryProvider
    status: DirectoryStatus
    mappings: _containers.RepeatedCompositeFieldContainer[DirectoryMapping]
    groups: _containers.RepeatedCompositeFieldContainer[ExternalGroup]
    def __init__(self, name: _Optional[str] = ..., directory_type: _Optional[_Union[DirectoryType, str]] = ..., enabled: bool = ..., directory_provider: _Optional[_Union[DirectoryProvider, str]] = ..., status: _Optional[_Union[DirectoryStatus, str]] = ..., mappings: _Optional[_Iterable[_Union[DirectoryMapping, _Mapping]]] = ..., groups: _Optional[_Iterable[_Union[ExternalGroup, _Mapping]]] = ...) -> None: ...

class UpdateDirectoryResponse(_message.Message):
    __slots__ = ("directory",)
    DIRECTORY_FIELD_NUMBER: _ClassVar[int]
    directory: Directory
    def __init__(self, directory: _Optional[_Union[Directory, _Mapping]] = ...) -> None: ...

class AssignGroupsForDirectoryRequest(_message.Message):
    __slots__ = ("id", "organization_id", "external_ids")
    ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_IDS_FIELD_NUMBER: _ClassVar[int]
    id: str
    organization_id: str
    external_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., organization_id: _Optional[str] = ..., external_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ListDirectoriesRequest(_message.Message):
    __slots__ = ("organization_id",)
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    def __init__(self, organization_id: _Optional[str] = ...) -> None: ...

class ListDirectoriesResponse(_message.Message):
    __slots__ = ("directories",)
    DIRECTORIES_FIELD_NUMBER: _ClassVar[int]
    directories: _containers.RepeatedCompositeFieldContainer[Directory]
    def __init__(self, directories: _Optional[_Iterable[_Union[Directory, _Mapping]]] = ...) -> None: ...

class ListDirectoryUsersRequest(_message.Message):
    __slots__ = ("organization_id", "directory_id", "page_size", "page_token", "include_detail", "directory_group_id", "updated_after")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_DETAIL_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AFTER_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    directory_id: str
    page_size: int
    page_token: str
    include_detail: bool
    directory_group_id: str
    updated_after: _timestamp_pb2.Timestamp
    def __init__(self, organization_id: _Optional[str] = ..., directory_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., include_detail: bool = ..., directory_group_id: _Optional[str] = ..., updated_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ListDirectoryUsersResponse(_message.Message):
    __slots__ = ("users", "total_size", "next_page_token", "prev_page_token")
    USERS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[DirectoryUser]
    total_size: int
    next_page_token: str
    prev_page_token: str
    def __init__(self, users: _Optional[_Iterable[_Union[DirectoryUser, _Mapping]]] = ..., total_size: _Optional[int] = ..., next_page_token: _Optional[str] = ..., prev_page_token: _Optional[str] = ...) -> None: ...

class ListDirectoryGroupsRequest(_message.Message):
    __slots__ = ("organization_id", "directory_id", "page_size", "page_token", "updated_after", "include_detail", "include_external_groups")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AFTER_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_DETAIL_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_EXTERNAL_GROUPS_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    directory_id: str
    page_size: int
    page_token: str
    updated_after: _timestamp_pb2.Timestamp
    include_detail: bool
    include_external_groups: bool
    def __init__(self, organization_id: _Optional[str] = ..., directory_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., updated_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., include_detail: bool = ..., include_external_groups: bool = ...) -> None: ...

class ListDirectoryGroupsResponse(_message.Message):
    __slots__ = ("groups", "total_size", "next_page_token", "prev_page_token")
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[DirectoryGroup]
    total_size: int
    next_page_token: str
    prev_page_token: str
    def __init__(self, groups: _Optional[_Iterable[_Union[DirectoryGroup, _Mapping]]] = ..., total_size: _Optional[int] = ..., next_page_token: _Optional[str] = ..., prev_page_token: _Optional[str] = ...) -> None: ...

class ListDirectoryGroupsSummaryRequest(_message.Message):
    __slots__ = ("organization_id", "directory_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    directory_id: str
    def __init__(self, organization_id: _Optional[str] = ..., directory_id: _Optional[str] = ...) -> None: ...

class Directory(_message.Message):
    __slots__ = ("id", "name", "directory_type", "organization_id", "enabled", "directory_provider", "last_synced_at", "directory_endpoint", "total_users", "total_groups", "secrets", "stats", "role_assignments", "attribute_mappings", "status", "email", "groups_tracked")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_TYPE_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    LAST_SYNCED_AT_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_USERS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_GROUPS_FIELD_NUMBER: _ClassVar[int]
    SECRETS_FIELD_NUMBER: _ClassVar[int]
    STATS_FIELD_NUMBER: _ClassVar[int]
    ROLE_ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    GROUPS_TRACKED_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    directory_type: DirectoryType
    organization_id: str
    enabled: bool
    directory_provider: DirectoryProvider
    last_synced_at: _timestamp_pb2.Timestamp
    directory_endpoint: str
    total_users: int
    total_groups: int
    secrets: _containers.RepeatedCompositeFieldContainer[Secret]
    stats: Stats
    role_assignments: RoleAssignments
    attribute_mappings: AttributeMappings
    status: str
    email: str
    groups_tracked: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., directory_type: _Optional[_Union[DirectoryType, str]] = ..., organization_id: _Optional[str] = ..., enabled: bool = ..., directory_provider: _Optional[_Union[DirectoryProvider, str]] = ..., last_synced_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., directory_endpoint: _Optional[str] = ..., total_users: _Optional[int] = ..., total_groups: _Optional[int] = ..., secrets: _Optional[_Iterable[_Union[Secret, _Mapping]]] = ..., stats: _Optional[_Union[Stats, _Mapping]] = ..., role_assignments: _Optional[_Union[RoleAssignments, _Mapping]] = ..., attribute_mappings: _Optional[_Union[AttributeMappings, _Mapping]] = ..., status: _Optional[str] = ..., email: _Optional[str] = ..., groups_tracked: _Optional[str] = ...) -> None: ...

class ToggleDirectoryRequest(_message.Message):
    __slots__ = ("organization_id", "id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    id: str
    def __init__(self, organization_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class ToggleDirectoryResponse(_message.Message):
    __slots__ = ("enabled", "error_message")
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    enabled: bool
    error_message: str
    def __init__(self, enabled: bool = ..., error_message: _Optional[str] = ...) -> None: ...

class DirectoryMapping(_message.Message):
    __slots__ = ("key", "map_to", "display_name")
    KEY_FIELD_NUMBER: _ClassVar[int]
    MAP_TO_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    key: str
    map_to: str
    display_name: str
    def __init__(self, key: _Optional[str] = ..., map_to: _Optional[str] = ..., display_name: _Optional[str] = ...) -> None: ...

class DirectoryUser(_message.Message):
    __slots__ = ("id", "email", "preferred_username", "given_name", "family_name", "updated_at", "emails", "groups", "user_detail")
    ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_USERNAME_FIELD_NUMBER: _ClassVar[int]
    GIVEN_NAME_FIELD_NUMBER: _ClassVar[int]
    FAMILY_NAME_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    EMAILS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    USER_DETAIL_FIELD_NUMBER: _ClassVar[int]
    id: str
    email: str
    preferred_username: str
    given_name: str
    family_name: str
    updated_at: _timestamp_pb2.Timestamp
    emails: _containers.RepeatedScalarFieldContainer[str]
    groups: _containers.RepeatedCompositeFieldContainer[DirectoryGroup]
    user_detail: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., email: _Optional[str] = ..., preferred_username: _Optional[str] = ..., given_name: _Optional[str] = ..., family_name: _Optional[str] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., emails: _Optional[_Iterable[str]] = ..., groups: _Optional[_Iterable[_Union[DirectoryGroup, _Mapping]]] = ..., user_detail: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class ExternalGroup(_message.Message):
    __slots__ = ("external_id", "display_name", "email")
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    external_id: str
    display_name: str
    email: str
    def __init__(self, external_id: _Optional[str] = ..., display_name: _Optional[str] = ..., email: _Optional[str] = ...) -> None: ...

class DirectoryGroup(_message.Message):
    __slots__ = ("id", "display_name", "total_users", "updated_at", "group_detail")
    ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_USERS_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    GROUP_DETAIL_FIELD_NUMBER: _ClassVar[int]
    id: str
    display_name: str
    total_users: int
    updated_at: _timestamp_pb2.Timestamp
    group_detail: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., display_name: _Optional[str] = ..., total_users: _Optional[int] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., group_detail: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class CreateDirectorySecretRequest(_message.Message):
    __slots__ = ("organization_id", "directory_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    directory_id: str
    def __init__(self, organization_id: _Optional[str] = ..., directory_id: _Optional[str] = ...) -> None: ...

class CreateDirectorySecretResponse(_message.Message):
    __slots__ = ("plain_secret", "secret")
    PLAIN_SECRET_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    plain_secret: str
    secret: Secret
    def __init__(self, plain_secret: _Optional[str] = ..., secret: _Optional[_Union[Secret, _Mapping]] = ...) -> None: ...

class RegenerateDirectorySecretRequest(_message.Message):
    __slots__ = ("organization_id", "directory_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    directory_id: str
    def __init__(self, organization_id: _Optional[str] = ..., directory_id: _Optional[str] = ...) -> None: ...

class RegenerateDirectorySecretResponse(_message.Message):
    __slots__ = ("plain_secret", "secret")
    PLAIN_SECRET_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    plain_secret: str
    secret: Secret
    def __init__(self, plain_secret: _Optional[str] = ..., secret: _Optional[_Union[Secret, _Mapping]] = ...) -> None: ...

class Secret(_message.Message):
    __slots__ = ("id", "create_time", "secret_suffix", "status", "expire_time", "last_used_time", "directory_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    SECRET_SUFFIX_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_TIME_FIELD_NUMBER: _ClassVar[int]
    LAST_USED_TIME_FIELD_NUMBER: _ClassVar[int]
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    create_time: _timestamp_pb2.Timestamp
    secret_suffix: str
    status: SecretStatus
    expire_time: _timestamp_pb2.Timestamp
    last_used_time: _timestamp_pb2.Timestamp
    directory_id: str
    def __init__(self, id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., secret_suffix: _Optional[str] = ..., status: _Optional[_Union[SecretStatus, str]] = ..., expire_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_used_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., directory_id: _Optional[str] = ...) -> None: ...

class Stats(_message.Message):
    __slots__ = ("total_users", "total_groups", "group_updated_at", "user_updated_at")
    TOTAL_USERS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_GROUPS_FIELD_NUMBER: _ClassVar[int]
    GROUP_UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    USER_UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    total_users: int
    total_groups: int
    group_updated_at: _timestamp_pb2.Timestamp
    user_updated_at: _timestamp_pb2.Timestamp
    def __init__(self, total_users: _Optional[int] = ..., total_groups: _Optional[int] = ..., group_updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., user_updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AssignRolesRequest(_message.Message):
    __slots__ = ("organization_id", "id", "role_assignments")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    id: str
    role_assignments: RoleAssignments
    def __init__(self, organization_id: _Optional[str] = ..., id: _Optional[str] = ..., role_assignments: _Optional[_Union[RoleAssignments, _Mapping]] = ...) -> None: ...

class RoleAssignments(_message.Message):
    __slots__ = ("assignments",)
    ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    assignments: _containers.RepeatedCompositeFieldContainer[RoleAssignment]
    def __init__(self, assignments: _Optional[_Iterable[_Union[RoleAssignment, _Mapping]]] = ...) -> None: ...

class AssignRolesResponse(_message.Message):
    __slots__ = ("role_assignments",)
    ROLE_ASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    role_assignments: RoleAssignments
    def __init__(self, role_assignments: _Optional[_Union[RoleAssignments, _Mapping]] = ...) -> None: ...

class RoleAssignment(_message.Message):
    __slots__ = ("group_id", "role_name", "role_id")
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_NAME_FIELD_NUMBER: _ClassVar[int]
    ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    role_name: str
    role_id: str
    def __init__(self, group_id: _Optional[str] = ..., role_name: _Optional[str] = ..., role_id: _Optional[str] = ...) -> None: ...

class UpdateAttributesRequest(_message.Message):
    __slots__ = ("organization_id", "id", "attribute_mapping")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_MAPPING_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    id: str
    attribute_mapping: AttributeMappings
    def __init__(self, organization_id: _Optional[str] = ..., id: _Optional[str] = ..., attribute_mapping: _Optional[_Union[AttributeMappings, _Mapping]] = ...) -> None: ...

class AttributeMappings(_message.Message):
    __slots__ = ("attributes",)
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    attributes: _containers.RepeatedCompositeFieldContainer[AttributeMapping]
    def __init__(self, attributes: _Optional[_Iterable[_Union[AttributeMapping, _Mapping]]] = ...) -> None: ...

class AttributeMapping(_message.Message):
    __slots__ = ("key", "map_to")
    KEY_FIELD_NUMBER: _ClassVar[int]
    MAP_TO_FIELD_NUMBER: _ClassVar[int]
    key: str
    map_to: str
    def __init__(self, key: _Optional[str] = ..., map_to: _Optional[str] = ...) -> None: ...

class UpdateAttributesResponse(_message.Message):
    __slots__ = ("attribute_mappings",)
    ATTRIBUTE_MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    attribute_mappings: AttributeMappings
    def __init__(self, attribute_mappings: _Optional[_Union[AttributeMappings, _Mapping]] = ...) -> None: ...

class DeleteDirectoryRequest(_message.Message):
    __slots__ = ("organization_id", "id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    id: str
    def __init__(self, organization_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class TriggerDirectorySyncRequest(_message.Message):
    __slots__ = ("directory_id", "organization_id")
    DIRECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    directory_id: str
    organization_id: str
    def __init__(self, directory_id: _Optional[str] = ..., organization_id: _Optional[str] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.errdetails import errdetails_pb2 as _errdetails_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ("id", "environment_id", "create_time", "update_time", "email", "external_id", "memberships", "user_profile", "metadata", "last_login")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBERSHIPS_FIELD_NUMBER: _ClassVar[int]
    USER_PROFILE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    LAST_LOGIN_FIELD_NUMBER: _ClassVar[int]
    id: str
    environment_id: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    email: str
    external_id: str
    memberships: _containers.RepeatedCompositeFieldContainer[_commons_pb2.OrganizationMembership]
    user_profile: _commons_pb2.UserProfile
    metadata: _containers.ScalarMap[str, str]
    last_login: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., environment_id: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., email: _Optional[str] = ..., external_id: _Optional[str] = ..., memberships: _Optional[_Iterable[_Union[_commons_pb2.OrganizationMembership, _Mapping]]] = ..., user_profile: _Optional[_Union[_commons_pb2.UserProfile, _Mapping]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., last_login: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateUserAndMembershipRequest(_message.Message):
    __slots__ = ("organization_id", "user", "send_invitation_email")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    SEND_INVITATION_EMAIL_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    user: CreateUser
    send_invitation_email: bool
    def __init__(self, organization_id: _Optional[str] = ..., user: _Optional[_Union[CreateUser, _Mapping]] = ..., send_invitation_email: bool = ...) -> None: ...

class CreateUserAndMembershipResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class UpdateUser(_message.Message):
    __slots__ = ("external_id", "user_profile", "metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    USER_PROFILE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    external_id: str
    user_profile: UpdateUserProfile
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, external_id: _Optional[str] = ..., user_profile: _Optional[_Union[UpdateUserProfile, _Mapping]] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class UpdateUserRequest(_message.Message):
    __slots__ = ("id", "external_id", "user")
    ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    id: str
    external_id: str
    user: UpdateUser
    def __init__(self, id: _Optional[str] = ..., external_id: _Optional[str] = ..., user: _Optional[_Union[UpdateUser, _Mapping]] = ...) -> None: ...

class UpdateUserResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class GetUserRequest(_message.Message):
    __slots__ = ("id", "external_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    external_id: str
    def __init__(self, id: _Optional[str] = ..., external_id: _Optional[str] = ...) -> None: ...

class GetUserResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class ListOrganizationUsersRequest(_message.Message):
    __slots__ = ("organization_id", "page_size", "page_token")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    page_size: int
    page_token: str
    def __init__(self, organization_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListOrganizationUsersResponse(_message.Message):
    __slots__ = ("next_page_token", "total_size", "users", "prev_page_token")
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    total_size: int
    users: _containers.RepeatedCompositeFieldContainer[User]
    prev_page_token: str
    def __init__(self, next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., users: _Optional[_Iterable[_Union[User, _Mapping]]] = ..., prev_page_token: _Optional[str] = ...) -> None: ...

class DeleteMembershipRequest(_message.Message):
    __slots__ = ("organization_id", "id", "external_id", "cascade")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CASCADE_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    id: str
    external_id: str
    cascade: bool
    def __init__(self, organization_id: _Optional[str] = ..., id: _Optional[str] = ..., external_id: _Optional[str] = ..., cascade: bool = ...) -> None: ...

class CreateMembershipRequest(_message.Message):
    __slots__ = ("organization_id", "membership", "id", "external_id", "send_invitation_email")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBERSHIP_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    SEND_INVITATION_EMAIL_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    membership: CreateMembership
    id: str
    external_id: str
    send_invitation_email: bool
    def __init__(self, organization_id: _Optional[str] = ..., membership: _Optional[_Union[CreateMembership, _Mapping]] = ..., id: _Optional[str] = ..., external_id: _Optional[str] = ..., send_invitation_email: bool = ...) -> None: ...

class CreateMembershipResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class ListUsersRequest(_message.Message):
    __slots__ = ("page_size", "page_token")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListUsersResponse(_message.Message):
    __slots__ = ("users", "next_page_token", "total_size", "prev_page_token")
    USERS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[User]
    next_page_token: str
    total_size: int
    prev_page_token: str
    def __init__(self, users: _Optional[_Iterable[_Union[User, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., prev_page_token: _Optional[str] = ...) -> None: ...

class SearchUsersRequest(_message.Message):
    __slots__ = ("query", "page_size", "page_token")
    QUERY_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    query: str
    page_size: int
    page_token: str
    def __init__(self, query: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class SearchUsersResponse(_message.Message):
    __slots__ = ("next_page_token", "total_size", "users", "prev_page_token")
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    total_size: int
    users: _containers.RepeatedCompositeFieldContainer[User]
    prev_page_token: str
    def __init__(self, next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., users: _Optional[_Iterable[_Union[User, _Mapping]]] = ..., prev_page_token: _Optional[str] = ...) -> None: ...

class DeleteUserRequest(_message.Message):
    __slots__ = ("id", "external_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    external_id: str
    def __init__(self, id: _Optional[str] = ..., external_id: _Optional[str] = ...) -> None: ...

class UpdateMembershipRequest(_message.Message):
    __slots__ = ("organization_id", "id", "external_id", "membership")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBERSHIP_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    id: str
    external_id: str
    membership: UpdateMembership
    def __init__(self, organization_id: _Optional[str] = ..., id: _Optional[str] = ..., external_id: _Optional[str] = ..., membership: _Optional[_Union[UpdateMembership, _Mapping]] = ...) -> None: ...

class UpdateMembership(_message.Message):
    __slots__ = ("roles", "metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ROLES_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedCompositeFieldContainer[_commons_pb2.Role]
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, roles: _Optional[_Iterable[_Union[_commons_pb2.Role, _Mapping]]] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CreateMembership(_message.Message):
    __slots__ = ("roles", "metadata", "inviter_email")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ROLES_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    INVITER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedCompositeFieldContainer[_commons_pb2.Role]
    metadata: _containers.ScalarMap[str, str]
    inviter_email: str
    def __init__(self, roles: _Optional[_Iterable[_Union[_commons_pb2.Role, _Mapping]]] = ..., metadata: _Optional[_Mapping[str, str]] = ..., inviter_email: _Optional[str] = ...) -> None: ...

class UpdateMembershipResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class SearchOrganizationUsersRequest(_message.Message):
    __slots__ = ("organization_id", "query", "page_size", "page_token")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    query: str
    page_size: int
    page_token: str
    def __init__(self, organization_id: _Optional[str] = ..., query: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class SearchOrganizationUsersResponse(_message.Message):
    __slots__ = ("next_page_token", "total_size", "users", "prev_page_token")
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    total_size: int
    users: _containers.RepeatedCompositeFieldContainer[User]
    prev_page_token: str
    def __init__(self, next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., users: _Optional[_Iterable[_Union[User, _Mapping]]] = ..., prev_page_token: _Optional[str] = ...) -> None: ...

class CreateUser(_message.Message):
    __slots__ = ("email", "external_id", "membership", "user_profile", "metadata")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBERSHIP_FIELD_NUMBER: _ClassVar[int]
    USER_PROFILE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    email: str
    external_id: str
    membership: CreateMembership
    user_profile: CreateUserProfile
    metadata: _containers.ScalarMap[str, str]
    def __init__(self, email: _Optional[str] = ..., external_id: _Optional[str] = ..., membership: _Optional[_Union[CreateMembership, _Mapping]] = ..., user_profile: _Optional[_Union[CreateUserProfile, _Mapping]] = ..., metadata: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CreateUserProfile(_message.Message):
    __slots__ = ("first_name", "last_name", "name", "locale", "phone_number", "metadata", "custom_attributes")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class CustomAttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    first_name: str
    last_name: str
    name: str
    locale: str
    phone_number: str
    metadata: _containers.ScalarMap[str, str]
    custom_attributes: _containers.ScalarMap[str, str]
    def __init__(self, first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., name: _Optional[str] = ..., locale: _Optional[str] = ..., phone_number: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., custom_attributes: _Optional[_Mapping[str, str]] = ...) -> None: ...

class UpdateUserProfile(_message.Message):
    __slots__ = ("first_name", "last_name", "name", "locale", "phone_number", "metadata", "custom_attributes")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class CustomAttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PHONE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    first_name: str
    last_name: str
    name: str
    locale: str
    phone_number: str
    metadata: _containers.ScalarMap[str, str]
    custom_attributes: _containers.ScalarMap[str, str]
    def __init__(self, first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., name: _Optional[str] = ..., locale: _Optional[str] = ..., phone_number: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., custom_attributes: _Optional[_Mapping[str, str]] = ...) -> None: ...

class Invite(_message.Message):
    __slots__ = ("organization_id", "user_id", "invited_by", "status", "created_at", "expires_at", "resent_at", "resent_count")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    INVITED_BY_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    RESENT_AT_FIELD_NUMBER: _ClassVar[int]
    RESENT_COUNT_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    user_id: str
    invited_by: str
    status: str
    created_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    resent_at: _timestamp_pb2.Timestamp
    resent_count: int
    def __init__(self, organization_id: _Optional[str] = ..., user_id: _Optional[str] = ..., invited_by: _Optional[str] = ..., status: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., resent_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., resent_count: _Optional[int] = ...) -> None: ...

class ResendInviteRequest(_message.Message):
    __slots__ = ("organization_id", "id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    id: str
    def __init__(self, organization_id: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class ResendInviteResponse(_message.Message):
    __slots__ = ("invite",)
    INVITE_FIELD_NUMBER: _ClassVar[int]
    invite: Invite
    def __init__(self, invite: _Optional[_Union[Invite, _Mapping]] = ...) -> None: ...

class ListUserRolesRequest(_message.Message):
    __slots__ = ("organization_id", "user_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    user_id: str
    def __init__(self, organization_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class ListUserRolesResponse(_message.Message):
    __slots__ = ("roles",)
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedCompositeFieldContainer[_commons_pb2.Role]
    def __init__(self, roles: _Optional[_Iterable[_Union[_commons_pb2.Role, _Mapping]]] = ...) -> None: ...

class AssignUserRolesRequest(_message.Message):
    __slots__ = ("organization_id", "user_id", "roles")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    user_id: str
    roles: _containers.RepeatedCompositeFieldContainer[AssignRoleRequest]
    def __init__(self, organization_id: _Optional[str] = ..., user_id: _Optional[str] = ..., roles: _Optional[_Iterable[_Union[AssignRoleRequest, _Mapping]]] = ...) -> None: ...

class AssignRoleRequest(_message.Message):
    __slots__ = ("id", "role_name")
    ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    role_name: str
    def __init__(self, id: _Optional[str] = ..., role_name: _Optional[str] = ...) -> None: ...

class AssignUserRolesResponse(_message.Message):
    __slots__ = ("roles",)
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedCompositeFieldContainer[_commons_pb2.Role]
    def __init__(self, roles: _Optional[_Iterable[_Union[_commons_pb2.Role, _Mapping]]] = ...) -> None: ...

class RemoveUserRoleRequest(_message.Message):
    __slots__ = ("organization_id", "user_id", "role_name")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_NAME_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    user_id: str
    role_name: str
    def __init__(self, organization_id: _Optional[str] = ..., user_id: _Optional[str] = ..., role_name: _Optional[str] = ...) -> None: ...

class ListUserPermissionsRequest(_message.Message):
    __slots__ = ("organization_id", "user_id")
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    user_id: str
    def __init__(self, organization_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class Permission(_message.Message):
    __slots__ = ("id", "name", "display_name", "description", "tags")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    display_name: str
    description: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...

class ListUserPermissionsResponse(_message.Message):
    __slots__ = ("permissions",)
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    permissions: _containers.RepeatedCompositeFieldContainer[Permission]
    def __init__(self, permissions: _Optional[_Iterable[_Union[Permission, _Mapping]]] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Provider(_message.Message):
    __slots__ = ("id", "identifier", "display_name", "description", "categories", "auth_patterns", "icon_src", "display_priority")
    ID_FIELD_NUMBER: _ClassVar[int]
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    AUTH_PATTERNS_FIELD_NUMBER: _ClassVar[int]
    ICON_SRC_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    id: str
    identifier: str
    display_name: str
    description: str
    categories: _containers.RepeatedScalarFieldContainer[str]
    auth_patterns: _struct_pb2.ListValue
    icon_src: str
    display_priority: int
    def __init__(self, id: _Optional[str] = ..., identifier: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., categories: _Optional[_Iterable[str]] = ..., auth_patterns: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ..., icon_src: _Optional[str] = ..., display_priority: _Optional[int] = ...) -> None: ...

class CreateProvider(_message.Message):
    __slots__ = ("identifier", "display_name", "description", "categories", "auth_patterns", "icon_src", "display_priority")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    AUTH_PATTERNS_FIELD_NUMBER: _ClassVar[int]
    ICON_SRC_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    display_name: str
    description: str
    categories: _containers.RepeatedScalarFieldContainer[str]
    auth_patterns: _struct_pb2.ListValue
    icon_src: str
    display_priority: int
    def __init__(self, identifier: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., categories: _Optional[_Iterable[str]] = ..., auth_patterns: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ..., icon_src: _Optional[str] = ..., display_priority: _Optional[int] = ...) -> None: ...

class CreateProviderRequest(_message.Message):
    __slots__ = ("provider",)
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    provider: CreateProvider
    def __init__(self, provider: _Optional[_Union[CreateProvider, _Mapping]] = ...) -> None: ...

class CreateProviderResponse(_message.Message):
    __slots__ = ("provider",)
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    provider: Provider
    def __init__(self, provider: _Optional[_Union[Provider, _Mapping]] = ...) -> None: ...

class UpdateProvider(_message.Message):
    __slots__ = ("display_name", "description", "categories", "auth_patterns", "icon_src", "display_priority")
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    AUTH_PATTERNS_FIELD_NUMBER: _ClassVar[int]
    ICON_SRC_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_PRIORITY_FIELD_NUMBER: _ClassVar[int]
    display_name: str
    description: str
    categories: _containers.RepeatedScalarFieldContainer[str]
    auth_patterns: _struct_pb2.ListValue
    icon_src: str
    display_priority: int
    def __init__(self, display_name: _Optional[str] = ..., description: _Optional[str] = ..., categories: _Optional[_Iterable[str]] = ..., auth_patterns: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ..., icon_src: _Optional[str] = ..., display_priority: _Optional[int] = ...) -> None: ...

class UpdateProviderRequest(_message.Message):
    __slots__ = ("identifier", "provider")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    provider: UpdateProvider
    def __init__(self, identifier: _Optional[str] = ..., provider: _Optional[_Union[UpdateProvider, _Mapping]] = ...) -> None: ...

class UpdateProviderResponse(_message.Message):
    __slots__ = ("provider",)
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    provider: Provider
    def __init__(self, provider: _Optional[_Union[Provider, _Mapping]] = ...) -> None: ...

class ListProvidersRequest(_message.Message):
    __slots__ = ("identifier", "page_size", "page_token")
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    page_size: int
    page_token: str
    def __init__(self, identifier: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListProvidersResponse(_message.Message):
    __slots__ = ("providers", "next_page_token", "total_size", "prev_page_token")
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    providers: _containers.RepeatedCompositeFieldContainer[Provider]
    next_page_token: str
    total_size: int
    prev_page_token: str
    def __init__(self, providers: _Optional[_Iterable[_Union[Provider, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ..., prev_page_token: _Optional[str] = ...) -> None: ...

class DeleteProviderRequest(_message.Message):
    __slots__ = ("identifier",)
    IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    identifier: str
    def __init__(self, identifier: _Optional[str] = ...) -> None: ...

class DeleteProviderResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...
